.. gptide documentation master file, created by
   sphinx-quickstart on Thu Jul 21 20:33:05 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

gptide: a lightweight module for Gaussian Process regression
=============================================================


Contents
--------

.. toctree::
   :maxdepth: 1

   api
   examples

